Informes | OiRA

Temas

# Informes

Puede utilizar un informe para:

- Aportar pruebas a las autoridades competentes.
- Transmitir información a las personas afectadas (trabajadores, delegados de prevención, empresarios, expertos en seguridad y salud en el trabajo, etc.).
- Supervisar y evaluar si se han adoptado las medidas necesarias.
- Registrar cualquier revisión si las circunstancias cambian (máquinas nuevas, trabajadores nuevos, como resultado de las conclusiones de cualquier investigación de accidentes, etc.).

Puede guardar el informe en su ordenador e imprimirlo. También lo puede modificar o añadir más información. Tenga en cuenta que los cambios realizados en un informe que ha descargado NO se guardarán en la herramienta OiRA.

## Tipos de informe

Existen diferentes tipos de informes disponibles para diferentes fines. La selección de los informes disponibles para las herramientas específicas depende de las decisiones adoptadas por el socio o el desarrollador nacional de la herramienta OiRA.

Informes disponibles

### Informe completo

Formato: Word/Office Open XML (.docx). Se puede editar después de haberlo descargado.

Proporciona: toda la información y las entradas que ha consignado durante el proceso de evaluación de riesgos.

Utilice el informe para:

- Aportar pruebas de la evaluación de riesgos a las autoridades competentes (Inspección de Trabajo).

### Plan de acción

Formato: Excel/Office Open XML (.xlsx). Se puede editar después de haberlo descargado.

Proporciona: información sobre todas las medidas que ha decidido adoptar.

Utilice el informe para:

- Hacer un seguimiento activo de la aplicación de las medidas por las que haya optado.
- Gestionar los riesgos en el puesto de trabajo (tareas específicas, conocimientos especializados, responsabilidades, plazos).

### Descripción general de los riesgos

Formato: formato de documento portátil (.pdf). No se puede editar después de haberlo descargado.

Proporciona: una visión general de los riesgos identificados.

Utilice el informe para:

- Obtener una visión general rápida del estado de los riesgos en su centro de trabajo.
- Transmitir información a las personas interesadas.
- Supervisar si se están tratando de modo adecuado los riesgos y las medidas.

### Visión general de las medidas

Formato: formato de documento portátil (.pdf). No se puede editar después de haberlo descargado.

Proporciona: una visión general rápida de las medidas que deben aplicarse.

Utilice el informe para:

- Obtener una visión general rápida del estado de las medidas que ha decidido aplicar.
- Transmitir información a las personas interesadas.
- Supervisar si los riesgos y las medidas se están tratando de modo adecuado.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More